pykakasi
=======

This is CONTRIBUTE.md for pykakasi project. Have a look at README.md 
for general project information.

Resources
--------

Project Manager: Hiroshi Miura
Mail list: none yet
Bug tracker: github issue tracker
Status: early alpha

Bug triage
--------

Every report to github issue tracker should be triaged
whether it is bug, question or invalid.


Send patch
--------

Here is small amount rule when you want to send patch the project;

1. every proposal for modification should send as 'Pull Request'

1. each pull request can consist of multiple commits.

1. you are encourage to split modifications to individual commits that are logical subpart.


